@@ -25,15 +25,13 @@ class Simulation:
         self.direction = axdict[databin_index]
         self.axis = np.array(self.data.dimensions[databin_index].get_bin_centers())
         unit = self.data.dimensions[databin_index].unit
-        if self.direction == "Z":
-            self.axis = np.flip(self.axis)
         self.axis = [self.convert_SI(x, unit) for x in self.axis]
         if "Mean" in self.data.statistics:
             scored_quantity = "Mean"
         if "Sum" in self.data.statistics:
             scored_quantity = "Sum"
         self.dose = self.data.data[scored_quantity]
-        self.dose = self.dose.flatten()
+        self.dose = np.flip(self.dose.flatten())
         self.unit = self.data.unit
 
         try:
@@ -85,23 +83,3 @@ class Simulation:
     def convert_SI(self, val, unit_in):
         SI = {"mm": 0.001, "cm": 0.01, "m": 1.0, "km": 1000.0}
         return val * SI[unit_in] / SI["mm"]
-
-
-class EGSSimulation:
-    def __init__(self, filepath):
-
-        self.filepath = filepath
-        self.filename = self.filepath.split("/")[-1][:-7]
-
-        self.direction = ""
-        self.unit = ""
-        self.dose = []
-        self.std_dev = []
-        self.axis = []
-
-        self.axis = {True: self.axis[len(self.axis) // 2 :], False: self.axis}
-        self.std_dev = {
-            True: self.std_dev[len(self.std_dev) // 2 :],
-            False: self.std_dev,
-        }
-        self.normpoint = max(self.dose)
